@@ -34,7 +34,7 @@ def inference(img_path,ocr,cvdnn_path):
             txts = [line[1][0] for line in result]
             scores = [line[1][1] for line in result]
             if len(txts)==0:          #no object detected
-                return "-1",float(0.0)  #object not found
+                return "500",float(0.0)  #object not found
             try: 
                 regex = '^[+-]?[0-9]+\.[0-9]$'
                 for i in range(0,len(txts)):# most repeating txts
@@ -49,7 +49,7 @@ def inference(img_path,ocr,cvdnn_path):
                         txts.pop(i)
                         scores.pop(i)
                 if len(txts)==0:
-                   return "-2",float(0.0) 
+                   return "500",float(0.0) 
                 txts=[mode(txts)]
                 scores=[max(scores)]
             except:
@@ -61,11 +61,11 @@ def inference(img_path,ocr,cvdnn_path):
             if(re.search(regex, txts[0])):
                     return str(txts[0]),float(scores[0])
             else:
-                    return "-2",float(0.0)
+                    return "500",float(0.0)
         else:
-            return "-3",float(0.0)  #could not configured
+            return "500",float(0.0)  #could not configured
     except Exception as E:
-        return "-4",float(0.0) # could not process,Exception
+        return "500",float(0.0) # could not process,Exception
 
 '''if __name__ == "__main__":
     txts,scores=inference("img2.jpg","en")
